==> haskell-libmpd-0.9.0.8-34-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-libmpd.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: libmpd
version: 0.9.0.8
id: libmpd-0.9.0.8-805Ehbc2Rut4zdETFL6bON
key: libmpd-0.9.0.8-805Ehbc2Rut4zdETFL6bON
license: MIT
copyright: Ben Sinclair 2005-2009, Joachim Fasting 2007-2015,
           Daniel Schoepe 2009, Andrzej Rybczak 2010,
           Simon Hengel 2011-2014, Niklas Haas 2012,
           Matvey Aksenov 2014, Wieland Hoffmann 2014,
           Tim Heap 2014, Tobias Brandt 2014
maintainer: Joachim Fasting <joachifm@fastmail.fm>
author: Ben Sinclair
stability: beta
homepage: http://github.com/vimus/libmpd-haskell#readme
synopsis: An MPD client library.
description:
    A client library for MPD, the Music Player Daemon.
category: Network, Sound
abi: 7881d7c57edf4cc9e837d094b25e1281
exposed: True
exposed-modules:
    Network.MPD Network.MPD.Applicative
    Network.MPD.Applicative.ClientToClient
    Network.MPD.Applicative.Connection
    Network.MPD.Applicative.CurrentPlaylist
    Network.MPD.Applicative.Database Network.MPD.Applicative.Output
    Network.MPD.Applicative.PlaybackControl
    Network.MPD.Applicative.PlaybackOptions
    Network.MPD.Applicative.Reflection Network.MPD.Applicative.Status
    Network.MPD.Applicative.Stickers
    Network.MPD.Applicative.StoredPlaylists
    Network.MPD.Commands.Extensions Network.MPD.Core
hidden-modules: Network.MPD.Core.Class Network.MPD.Core.Error
                Network.MPD.Commands Network.MPD.Commands.Arg
                Network.MPD.Commands.Parse Network.MPD.Commands.Query
                Network.MPD.Commands.Types Network.MPD.Commands.ClientToClient
                Network.MPD.Commands.Status Network.MPD.Commands.PlaybackOptions
                Network.MPD.Commands.PlaybackControl
                Network.MPD.Commands.CurrentPlaylist
                Network.MPD.Commands.StoredPlaylists Network.MPD.Commands.Database
                Network.MPD.Commands.Stickers Network.MPD.Commands.Connection
                Network.MPD.Commands.Output Network.MPD.Commands.Reflection
                Network.MPD.Applicative.Util Network.MPD.Applicative.Internal
                Network.MPD.Util
import-dirs: /usr/lib/ghc-8.4.3/site-local/libmpd-0.9.0.8
library-dirs: /usr/lib/ghc-8.4.3/site-local/libmpd-0.9.0.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/libmpd-0.9.0.8
hs-libraries: HSlibmpd-0.9.0.8-805Ehbc2Rut4zdETFL6bON
depends:
    base-4.11.1.0 attoparsec-0.13.2.2-EIztAESN4La3Q2n7ylOy7n
    bytestring-0.10.8.2 containers-0.5.11.0 filepath-1.4.2 mtl-2.2.2
    old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh text-1.2.3.0
    data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j
    network-2.7.0.2-2ShKE4Ejgp6Bq9Qkb7AIP
    utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8 time-1.8.0.2
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             attoparsec-0.13.2.2-EIztAESN4La3Q2n7ylOy7n=5f8c3cf6b8ae475d94bd0da5607b091c
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh=624bb9fc159afd36b39208b6844f8edd
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j=64b4bc7e44050b1acf530e79a106effe
             network-2.7.0.2-2ShKE4Ejgp6Bq9Qkb7AIP=febca036f4f0db50e6534d133a8b12c8
             utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8=2191a818a7f61b012f58bd96949826c6
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
haddock-interfaces: /usr/share/doc/haskell-libmpd/html/libmpd.haddock
haddock-html: /usr/share/doc/haskell-libmpd/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-libmpd-0.9.0.8-37-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-libmpd.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: libmpd
version: 0.9.0.8
id: libmpd-0.9.0.8-95tvCIy7T5s9qsnjbK7gRz
key: libmpd-0.9.0.8-95tvCIy7T5s9qsnjbK7gRz
license: MIT
copyright: Ben Sinclair 2005-2009, Joachim Fasting 2007-2015,
           Daniel Schoepe 2009, Andrzej Rybczak 2010,
           Simon Hengel 2011-2014, Niklas Haas 2012,
           Matvey Aksenov 2014, Wieland Hoffmann 2014,
           Tim Heap 2014, Tobias Brandt 2014
maintainer: Joachim Fasting <joachifm@fastmail.fm>
author: Ben Sinclair
stability: beta
homepage: http://github.com/vimus/libmpd-haskell#readme
synopsis: An MPD client library.
description:
    A client library for MPD, the Music Player Daemon.
category: Network, Sound
abi: 39e1f0a42c41cba3d9efcbf538a3cdd6
exposed: True
exposed-modules:
    Network.MPD Network.MPD.Applicative
    Network.MPD.Applicative.ClientToClient
    Network.MPD.Applicative.Connection
    Network.MPD.Applicative.CurrentPlaylist
    Network.MPD.Applicative.Database Network.MPD.Applicative.Output
    Network.MPD.Applicative.PlaybackControl
    Network.MPD.Applicative.PlaybackOptions
    Network.MPD.Applicative.Reflection Network.MPD.Applicative.Status
    Network.MPD.Applicative.Stickers
    Network.MPD.Applicative.StoredPlaylists
    Network.MPD.Commands.Extensions Network.MPD.Core
hidden-modules: Network.MPD.Core.Class Network.MPD.Core.Error
                Network.MPD.Commands Network.MPD.Commands.Arg
                Network.MPD.Commands.Parse Network.MPD.Commands.Query
                Network.MPD.Commands.Types Network.MPD.Commands.ClientToClient
                Network.MPD.Commands.Status Network.MPD.Commands.PlaybackOptions
                Network.MPD.Commands.PlaybackControl
                Network.MPD.Commands.CurrentPlaylist
                Network.MPD.Commands.StoredPlaylists Network.MPD.Commands.Database
                Network.MPD.Commands.Stickers Network.MPD.Commands.Connection
                Network.MPD.Commands.Output Network.MPD.Commands.Reflection
                Network.MPD.Applicative.Util Network.MPD.Applicative.Internal
                Network.MPD.Util
import-dirs: /usr/lib/ghc-8.4.3/site-local/libmpd-0.9.0.8
library-dirs: /usr/lib/ghc-8.4.3/site-local/libmpd-0.9.0.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/libmpd-0.9.0.8
hs-libraries: HSlibmpd-0.9.0.8-95tvCIy7T5s9qsnjbK7gRz
depends:
    base-4.11.1.0 attoparsec-0.13.2.2-LRNbjQIitwn4Jmo3hCxwCI
    bytestring-0.10.8.2 containers-0.5.11.0 filepath-1.4.2 mtl-2.2.2
    old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh text-1.2.3.0
    data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j
    network-2.7.0.2-DHEaxB3Qzor483iLxewsye
    utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8 time-1.8.0.2
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             attoparsec-0.13.2.2-LRNbjQIitwn4Jmo3hCxwCI=4a615f6f9c3fdb3bc12ed255f597d820
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh=624bb9fc159afd36b39208b6844f8edd
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j=64b4bc7e44050b1acf530e79a106effe
             network-2.7.0.2-DHEaxB3Qzor483iLxewsye=6aeecf5609d81737c1dbc231763db621
             utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8=2191a818a7f61b012f58bd96949826c6
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
haddock-interfaces: /usr/share/doc/haskell-libmpd/html/libmpd.haddock
haddock-html: /usr/share/doc/haskell-libmpd/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
